
# The following is code written in R (www.r-project.org)
# to replicate the results of 
# "Effects of quality claims on willingness to pay for organic food. 
# Evidence from Experimental Auctions in Croatia"
# Marin Cagalj, Rainer Haas and Ulrich Morawetz
# to be published in the "Britsh Food Journal"

 # clear everything currently in the working directory
 # only run if you are sure you want to clear your working directory
 rm(list=ls())

# Set the working directory to the directory where the data "Ea_PhD_CRO_final.csv" is located
  #setwd( "E:/home/mydata/")
  setwd( "E:\\uli\\communication\\Marin_Cagal\\data_analysis\\")

## load the required libraries. In order to be able to loade them, they have to be installed at 
  # the computerer e.g. install.packages("plm")
  library(plm)
  library(car)
  library(lmtest)
 
 
 ##load data table
    regdata<-read.csv("Ea_PhD_CRO_final.csv",header=TRUE,sep=",")
  # A descrption of the variables is available in the file "Data_Description.xlsx"  
    
 ######################
  # Change reference category and set variable type for some variables
 
   # make "male" reference category for gender variable
     regdata$gender<-relevel(regdata$gender,ref="male")
   
   #make "yes" reference category for planed to buy today variable
    regdata$plan.buy_today<-relevel(regdata$plan.buy_today,ref="yes")
 
  #make "yes" reference category for buyers of organic food variable
     regdata$plan.buy_today<-relevel(regdata$plan.buy_today,ref="yes")

  #make "envir" reference category for claim variable
   regdata$which_cl<-relevel(regdata$which_cl,ref="envir")

  # make income factor
   regdata$income <- as.factor(regdata$income)
   
  # make income factor
   regdata$education <- as.factor(regdata$education)

 # make a variable for "university degree"
   regdata$uni <- "no"
   regdata$uni[regdata$education==1] <- "yes"
   regdata$uni<- as.factor(regdata$uni)
  
 # make a variable for a respondent's household having children
  regdata$children.temp <- NA
  regdata$children.temp[regdata$children==1]<-"yes"
  regdata$children.temp[regdata$children==2]<-"no"
  regdata$children<-regdata$children.temp
  regdata$children<-as.factor(regdata$children.temp)
  regdata$children.temp<-NULL
  
  

#######################
### Write function to generate descriptive statistics
  
 
  # function for descrete variables:
  desstat.discrete<-function(variable.name, characteristic.of.interest, dataset=NULL,percentage=TRUE){
                       data     <-  dataset
                       variable <-  data[[variable.name]]
                       index1   <-  data[[variable.name]] == characteristic.of.interest
                       index2   <-  is.na(data[[variable.name]])== FALSE
                       mean <-length(na.omit(variable[index1]))/
                              length(na.omit(variable[index2]))
                       sd   <-sd( c(
                       rep(1,times= (length(na.omit(variable[index1])))),
                       rep(0,times= (length(na.omit(variable[index2])) - length(na.omit(variable[index1]))) )
                       ))
                       if(percentage==TRUE){
                       mean<-mean*100
                       sd<-sd*100}
                       return(c(mean,sd))                      }
   
   # function for continuous variables:                     
      desstat.continuous<-function(variable.name, dataset=NULL){
                      data      <-  dataset
                      variable  <-  dataset[[variable.name]]
                      mean      <-  mean(variable, na.rm=TRUE)
                      sd        <-  sd(variable, na.rm=TRUE)
                      return(c(mean,sd))                     }



  #### make matrix with descriptive statistics of participant characteristic
   des.A_T_bids<-rbind(
     desstat.continuous(variable.name="age", dataset=regdata),
     desstat.discrete(variable.name="gender",characteristic.of.interest="male", dataset=regdata, percentage="TRUE"),
     desstat.discrete(variable.name="children",characteristic.of.interest="yes", dataset=regdata, percentage="TRUE"),
     desstat.discrete(variable.name="uni",characteristic.of.interest="yes", dataset=regdata, percentage="TRUE"),
     # desstat.continuous(variable.name="education",dataset=regdata),
     desstat.discrete(variable.name="know_of", characteristic.of.interest="yes",dataset=regdata, percentage=TRUE),
     desstat.discrete(variable.name="plan.buy_today", characteristic.of.interest="yes",dataset=regdata, percentage=TRUE),
     desstat.discrete(variable.name="buy_of", characteristic.of.interest="yes", dataset=regdata, percentage=TRUE),
     # desstat.continuous(variable.name="income", dataset=regdata),
     c(nrow(regdata[regdata$which_claim=="envir",]),NA ))


  rownames(des.A_T_bids)<- c("Age(years)","Male(%)",
                           "Children in household (%)",
                           "Holds university degree (%)",
                           "Know of organic food(%)","Planned to buy today(%)", "Ever bought organic", 
                           #"Income (number)",
                           "No. observations")
 
    colnames(des.A_T_bids) <- c("Mean", "St. Dev.")
    des.A_T_bids

    des.categorial_vars<- cbind(  c(  table(regdata$income)/sum(table(regdata$income)),                                  
                                  table(regdata$edu)   /sum(table(regdata$income))),
                                  rep(NA, times=8))
    
    rownames(des.categorial_vars) <- c("Income > 15000 Euro/year", 
                    "Income  15000 - 10000 Euro/year",
                    "Income < 10000 Euro/year",
                    "Other",
                    "University",
                    "High School ",
                    "Elementary School",
                    "Other"
                     )
       colnames(des.categorial_vars)<-c("%", " ")

    ### write descriptive statistics to files
      write.csv(des.A_T_bids, "descriptive_stats_tab1.csv" )
      write.csv(des.categorial_vars, "descriptive_stats_tab2.csv" )



# make dataset  suitable for abalysis of bids from BDM experiment
    A_T_bids.data<-regdata

    # make matrix with bids statistics   

      desBids.A_T_bids<-rbind(
                      desstat.continuous(variable.name="test_noi_bd1",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_noi_bd2",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_noi_bd3",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_noi_bd4",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_gb_bd1",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_ngb_bd2",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_ngb_bd3",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_gb_bd4",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_gbm_bd1",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_ngbm_bd2",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_ngbm_bd3",dataset=A_T_bids.data),
                      desstat.continuous(variable.name="test_gbm_bd4",dataset=A_T_bids.data),desstat.continuous(variable.name="treat_noi_apple_con",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_noi_apple_org",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_noi_tomato_con",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_noi_tomato_org",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_prod_apple_con",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_prod_apple_org",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_prod_tomato_con",dataset=regdata[]),
                       desstat.continuous(variable.name="treat_prod_tomato_org",dataset=regdata[]),desstat.continuous(variable.name="treat_claim_apple_con"  ,dataset=regdata[regdata$which_claim=="envir",]),
                       desstat.continuous(variable.name="treat_claim_apple_org"  ,dataset=regdata[regdata$which_claim=="envir",]),
                       desstat.continuous(variable.name="treat_claim_tomato_con" ,dataset=regdata[regdata$which_claim=="envir",]),
                       desstat.continuous(variable.name="treat_claim_tomato_org" ,dataset=regdata[regdata$which_claim=="envir",]),desstat.continuous(variable.name="treat_claim_apple_con"  ,dataset=regdata[regdata$which_claim=="taste",]),
                       desstat.continuous(variable.name="treat_claim_apple_org"  ,dataset=regdata[regdata$which_claim=="taste",]),
                       desstat.continuous(variable.name="treat_claim_tomato_con",dataset=regdata[regdata$which_claim=="taste",]),
                       desstat.continuous(variable.name="treat_claim_tomato_org",dataset=regdata[regdata$which_claim=="taste",]),desstat.continuous(variable.name="treat_claim_apple_con"  ,dataset=regdata[regdata$which_claim=="health",]),
                       desstat.continuous(variable.name="treat_claim_apple_org"  ,dataset=regdata[regdata$which_claim=="health",]),
                       desstat.continuous(variable.name="treat_claim_tomato_con" ,dataset=regdata[regdata$which_claim=="health",]),                      desstat.continuous(variable.name="treat_claim_tomato_org" ,dataset=regdata[regdata$which_claim=="health",]),c( nrow(regdata[regdata$which_claim=="envir",]),NA)  )

           colnames(desBids.A_T_bids) <- c("Mean", "St. Dev.")

           rownames(desBids.A_T_bids)<-c("Bids 1st test round no information cg1",
                              "Bids 1st test round no information cg2",
                              "Bids 1st test round no information cg3",
                              "Bids 1st test round no information cg4",
                              "Bids 2nd test round gb1",
                              "Bids 2nd test round ngb2",
                              "Bids 2nd test round ngb3",
                              "Bids 2nd test round gb4",
                              "Bids 3rd test round gbm1",
                              "Bids 3rd test round ngbm2",
                              "Bids 3rd test round ngbm3",
                              "Bids 3rd test round gbm4",
                              "BDM bids 1st round no info A_C",
                              "BDM bids 1st round no info A_O",
                              "BDM bids 1st round no info T_C",
                              "BDM bids 1st round no info T_O",
                              "BDM bids 2nd round prod_A_C",
                              "BDM bids 2nd round prod_A_O",
                              "BDM bids 2nd round prod_T_C",
                              "BDM bids 2nd round prod_T_O",
                              "BDM bids 3rd round environmental claim A_C",
                              "BDM bids 3rd round environmental claim A_O",
                              "BDM bids 3rd round environmental claim T_C",
                              "BDM bids 3rd round environmental claim T_O",
                              "BDM bids 3rd round taste claim A_C",
                              "BDM bids 3rd round taste claim A_O",
                              "BDM bids 3rd round taste claim T_C",
                              "BDM bids 3rd round taste claim T_O",
                              "BDM bids 3rd round health claim A_C",
                              "BDM bids 3rd round health claim A_O",
                              "BDM bids 3rd round health claim T_C",
                              "BDM bids 3rd round health claim T_O",
                              "No. observations")

             descrBids.stats<-cbind(desBids.A_T_bids)

            descrBids.stats

# Analyze test round first (not in the article)            
     ######################
     # Difference between bids of 1st and 2nd test round for Chewing gum no. 1
      t.test(x =  A_T_bids.data$"test_noi_bd1",
            y = A_T_bids.data$"test_gb_bd1",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
      # Difference between bids 1st and 3rd test round for Chewing gum no. 1
        t.test(x =  A_T_bids.data$"test_noi_bd1",
            y = A_T_bids.data$"test_gbm_bd1",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
      # Difference between bids 2nd and 3rd test round for Chewing gum no. 1

       t.test(x =  A_T_bids.data$"test_gb_bd1",
            y = A_T_bids.data$"test_gbm_bd1",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
      ######################
      # Difference between bids of 1st and 2nd test round for Chewing gum no. 2
       t.test(x =  A_T_bids.data$"test_noi_bd2",
            y = A_T_bids.data$"test_ngb_bd2",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)

      # Difference between bids 1st and 3rd test round for Chewing gum no. 2
       t.test(x =  A_T_bids.data$"test_noi_bd2",
            y = A_T_bids.data$"test_ngbm_bd2",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)

     # Difference between bids 2nd and 3rd test round for Chewing gum no. 2
       t.test(x =  A_T_bids.data$"test_ngb_bd2",
            y = A_T_bids.data$"test_ngbm_bd2",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
     ######################
      # Difference between bids of 1st and 2nd test round for Chewing gum no. 3
        t.test(x =  A_T_bids.data$"test_noi_bd3",
            y = A_T_bids.data$"test_ngb_bd3",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
      # Difference between bids 1st and 3rd test round for Chewing gum no. 3
        t.test(x =  A_T_bids.data$"test_noi_bd3",
            y = A_T_bids.data$"test_ngbm_bd3",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
     # Difference between bids 2nd and 3rd test round for Chewing gum no. 3
        t.test(x =  A_T_bids.data$"test_ngb_bd3",
            y = A_T_bids.data$"test_ngbm_bd3",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)

     ######################
      # Difference between bids of 1st and 2nd test round for Chewing gum no. 4
         t.test(x =  A_T_bids.data$"test_noi_bd4",
            y = A_T_bids.data$"test_gb_bd4",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
     # Difference between bids 1st and 3rd test round for Chewing gum no. 4
        t.test(x =  A_T_bids.data$"test_noi_bd4",
            y = A_T_bids.data$"test_gbm_bd4",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
     # Difference between bids 2nd and 3rd test round for Chewing gum no. 4
        t.test(x =  A_T_bids.data$"test_gb_bd4",
            y = A_T_bids.data$"test_gbm_bd4",
            alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)


##########################################
### Differences between bids for Apple's 
    # Between 1st and 2nd round Apples conventional
     t.test(x=A_T_bids.data$"treat_noi_apple_con",y=A_T_bids.data$"treat_prod_apple_con", alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
    # Between 1st and 3rd round Apples conventional
     t.test(x=A_T_bids.data$"treat_noi_apple_con",y=A_T_bids.data$"treat_claim_apple_con", alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples conventional
     t.test(x=A_T_bids.data$"treat_prod_apple_con",y=A_T_bids.data$"treat_claim_apple_con", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples conventional claim environment
          t.test(x=A_T_bids.data$"treat_prod_apple_con",y=A_T_bids.data$"treat_claim_apple_con"[A_T_bids.data$which_claim=="envir"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples conventional claim taste
          t.test(x=A_T_bids.data$"treat_prod_apple_con",y=A_T_bids.data$"treat_claim_apple_con"[A_T_bids.data$which_claim=="taste"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples conventional claim health
          t.test(x=A_T_bids.data$"treat_prod_apple_con",y=A_T_bids.data$"treat_claim_apple_con"[A_T_bids.data$which_claim=="health"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 1st and 2nd round Apples organic
      t.test(x=A_T_bids.data$"treat_noi_apple_org",y=A_T_bids.data$"treat_prod_apple_org", alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
    # Between 1st and 3rd round Apples organic
      t.test(x=A_T_bids.data$"treat_noi_apple_org",y=A_T_bids.data$"treat_claim_apple_org", alternative = c("two.sided"),
            mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples organic
      t.test(x=A_T_bids.data$"treat_prod_apple_org",y=A_T_bids.data$"treat_claim_apple_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples organic claim environment
         t.test(x=A_T_bids.data$"treat_prod_apple_org",y=A_T_bids.data$"treat_claim_apple_org"[A_T_bids.data$which_claim=="envir"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples organic claim taste
          t.test(x=A_T_bids.data$"treat_prod_apple_org",y=A_T_bids.data$"treat_claim_apple_org"[A_T_bids.data$which_claim=="taste"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between 2nd and 3rd round Apples organic claim health
          t.test(x=A_T_bids.data$"treat_prod_apple_org",y=A_T_bids.data$"treat_claim_apple_org"[A_T_bids.data$which_claim=="health"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)


########################
### Differences between bids for tomatoes
    # Between 1st and 2nd round Tomatoes conventional
      t.test(x=A_T_bids.data$"treat_noi_tomato_con",y=A_T_bids.data$"treat_prod_tomato_con", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 1st and 3rd round Tomatoes conventional
      t.test(x=A_T_bids.data$"treat_noi_tomato_con",y=A_T_bids.data$"treat_claim_tomato_con", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes conventional
      t.test(x=A_T_bids.data$"treat_prod_tomato_con",y=A_T_bids.data$"treat_claim_tomato_con", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes conventional environmental claims 
          t.test(x=A_T_bids.data$"treat_prod_tomato_con",y=A_T_bids.data$"treat_claim_tomato_con"[A_T_bids.data$which_claim=="envir"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes conventional taste claims 
          t.test(x=A_T_bids.data$"treat_prod_tomato_con",y=A_T_bids.data$"treat_claim_tomato_con"[A_T_bids.data$which_claim=="taste"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes conventional environmental claims 
          t.test(x=A_T_bids.data$"treat_prod_tomato_con",y=A_T_bids.data$"treat_claim_tomato_con"[A_T_bids.data$which_claim=="health"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
   # Between 1st and 2nd round Tomatoes organic
     t.test(x=A_T_bids.data$"treat_noi_tomato_org",y=A_T_bids.data$"treat_prod_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 1st and 3rd round Tomatoes organic
     t.test(x=A_T_bids.data$"treat_noi_tomato_org",y=A_T_bids.data$"treat_claim_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes organic
     t.test(x=A_T_bids.data$"treat_prod_tomato_org",y=A_T_bids.data$"treat_claim_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes organic claim environment
             t.test(x=A_T_bids.data$"treat_prod_tomato_org",y=A_T_bids.data$"treat_claim_tomato_org"[A_T_bids.data$which_claim=="envir"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes organic claim taste
             t.test(x=A_T_bids.data$"treat_prod_tomato_org",y=A_T_bids.data$"treat_claim_tomato_org"[A_T_bids.data$which_claim=="taste"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between 2nd and 3rd round Tomatoes organic claim health
             t.test(x=A_T_bids.data$"treat_prod_tomato_org",y=A_T_bids.data$"treat_claim_tomato_org"[A_T_bids.data$which_claim=="health"], alternative = c("two.sided"),mu = 0,  var.equal = FALSE)

######################################
### Differences between bids for Apple's conventional and organic
    # Between Apples organic and conventional 1st round
      t.test(x=A_T_bids.data$"treat_noi_apple_con",y=A_T_bids.data$"treat_noi_apple_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between Apples organic and conventional 2nd round
      t.test(x=A_T_bids.data$"treat_prod_apple_con",y=A_T_bids.data$"treat_prod_apple_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    # Between Apples organic and conventional 3rd round
      t.test(x=A_T_bids.data$"treat_claim_apple_con",y=A_T_bids.data$"treat_claim_apple_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
###############################
### Differences between bids for Tomatoe's conventional and organic
    #Between Tomatoes organic and conventional 1st round
     t.test(x=A_T_bids.data$"treat_noi_tomato_con",y=A_T_bids.data$"treat_noi_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between tomatoes organic and conventional 2nd round
     t.test(x=A_T_bids.data$"treat_prod_tomato_con",y=A_T_bids.data$"treat_prod_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)
    #Between tomatoes organic and conventional 3rd round
     t.test(x=A_T_bids.data$"treat_claim_tomato_con",y=A_T_bids.data$"treat_claim_tomato_org", alternative = c("two.sided"),mu = 0,  var.equal = FALSE)

#####
# calculate p-value for difference between market price and first round bid
  #  Organiac apples
    # T=(mean(bids)-market price)/(sigma/158^.5)
    # critical value qt(.025,df=157)
    A.org.diff <- (1.32-2.25)/(0.59/16) 
     (1-pt( abs(A.org.diff) ,df=157))*2
    #  Conventional apples
    A.con.diff<- (1.28-1.32)/(0.59/16) 
     (1-pt( abs(A.con.diff) ,df=157))*2
    # Organic Tomatoes 
    T.org.diff<- (1.31-2.78)/(0.57/16) 
     (1-pt( abs(T.org.diff) ,df=157))*2
    # Conventional Tomatoes
     T.con.diff<- (1.37-1.52)/(0.65/16) 
      (1-pt( abs(T.con.diff) ,df=157))*2


########################
## make a dataset in "long" format for regressions containing the variables used in the regression
# create a dataset with the variables used in the regression

  attach(regdata)
    reg_dat<-cbind(regdata[,c("person_nr", "treat_noi_apple_con", "treat_noi_apple_org", "treat_noi_tomato_con", 
      	"treat_noi_tomato_org","treat_prod_apple_con","treat_prod_apple_org","treat_prod_tomato_con","treat_prod_tomato_org",
                          "treat_claim_apple_con","treat_claim_apple_org","treat_claim_tomato_con","treat_claim_tomato_org",
        "age","gender","education","know_of","plan.buy_today","buy_of","income", "uni", "eat_lt", "oft.buy_A", "oft.buy_T", "household_A", "household_T",
      	"plan.buy_today","children","employment","timeofday", "place", "loc.buy", "oft.buy_of", "cash", "time_decimal_start" )])
 detach(regdata)

  # create a long data set out of the reg_dat
  		reg_dat_long<-reshape(regdata,
				varying=list(c("treat_noi_apple_con", "treat_noi_apple_org", "treat_noi_tomato_con", 
  			"treat_noi_tomato_org","treat_prod_apple_con","treat_prod_apple_org","treat_prod_tomato_con","treat_prod_tomato_org",
                          "treat_claim_apple_con","treat_claim_apple_org","treat_claim_tomato_con","treat_claim_tomato_org")),
				v.names = c("bids"),
				timevar=c("treatment"),
				times=c("noi_apple_con"  , "noi_apple_org",   "noi_tomato_con",   "noi_tomato_org" , 
                "prod_apple_con",  "prod_apple_org",  "prod_tomato_con",  "prod_tomato_org",
				        "claim_apple_con", "claim_apple_org", "claim_tomato_con", "claim_tomato_org"),
				idvar="person_nr",
				direction="long")
  # remove the rownames, they don't make sense
  rownames(reg_dat_long) <- NULL
  

  # change variable treatment levels of "claim_apple_con"  "claim_apple_org" "claim_tomato_con" "claim_tomato_org"
  # accoring to the claim
 
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_con" & reg_dat_long$which_claim=="envir"] <-"claim_apple_con_envir" 
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_org" & reg_dat_long$which_claim=="envir"] <-"claim_apple_org_envir"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_con" & reg_dat_long$which_claim=="envir"] <-"claim_tomato_con_envir"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_org" & reg_dat_long$which_claim=="envir"] <-"claim_tomato_org_envir"

     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_con" & reg_dat_long$which_claim=="health"] <-"claim_apple_con_health" 
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_org" & reg_dat_long$which_claim=="health"] <-"claim_apple_org_health"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_con" & reg_dat_long$which_claim=="health"] <-"claim_tomato_con_health"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_org" & reg_dat_long$which_claim=="health"] <-"claim_tomato_org_health"

     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_con" & reg_dat_long$which_claim=="taste"] <-"claim_apple_con_taste" 
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_apple_org" & reg_dat_long$which_claim=="taste"] <-"claim_apple_org_taste"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_con" & reg_dat_long$which_claim=="taste"] <-"claim_tomato_con_taste"
     reg_dat_long$treatment[reg_dat_long$treatment=="claim_tomato_org" & reg_dat_long$which_claim=="taste"] <-"claim_tomato_org_taste"

     # drop the variable "which_claim" and "which_cl", it is misleading now

     reg_dat_long <- reg_dat_long[,- grep( "which_cl",names(reg_dat_long)) ]

##########################
# Prepare data for the test auction which are later used in the SUR model (not in the article)
     
     reg_dat_longGum<-reshape(regdata,
                         varying=list(c("test_noi_bd1", "test_noi_bd2", "test_noi_bd3", "test_noi_bd4", 
                                        "test_gb_bd1","test_ngb_bd2","test_ngb_bd3","test_gb_bd4",
                                        "test_gbm_bd1","test_ngbm_bd2","test_ngbm_bd3","test_gbm_bd4")),
                         v.names = c("bidsGum"),
                         timevar=c("treatmentGum"),
                         times=c("noi_gum1_good"  , "noi_gum1_notgood",   "noi_gum2_notgood",   "noi_gum2_good" , 
                                 "info_gum1_good",  "info_gum1_notgood",  "info_gum2_notgood",  "info_gum2_good",
                                 "video_gum1_good", "video_gum1_notgood", "video_gum2_notgood", "video_gum2_good"),
                         idvar="person_nr",
                         direction="long")
     # remove the rownames, they don't make sense
          rownames(reg_dat_longGum) <- NULL

##########################
### prepare data sets for apples, tomatees and the two types of chewing gums
  
     ## Make a dataset for apples only
      apple <-  reg_dat_long[grep( "apple" , reg_dat_long$treatment),]
      apple$treatment<-  as.factor(apple$treatment)
     # make no info conventional to reference group
      apple$treatment <- relevel(apple$treatment, ref = "noi_apple_con")

     ## Make a dataset for tomatos only
      tomato <-  reg_dat_long[grep( "tomato" , reg_dat_long$treatment),]
      tomato$treatment<-  as.factor(tomato$treatment)
     # make no info conventional to reference group
      tomato$treatment <- relevel(tomato$treatment, ref = "noi_tomato_con")


     ## Make a dataset for gum1 (the first type of chewing gum) only
       gum1 <-  reg_dat_longGum[grep( "gum1" , reg_dat_longGum$treatmentGum),]
       gum1$treatmentGum<-  as.factor(gum1$treatmentGum)
      # make no info conventional to reference group
       gum1$treatmentGum <- relevel(gum1$treatmentGum, ref = "noi_gum1_notgood")


      ## Make a dataset for gum2 (the second type of chewing gum) only
       gum2 <-  reg_dat_longGum[grep( "gum2" , reg_dat_longGum$treatmentGum),]
       gum2$treatmentGum<-  as.factor(gum2$treatmentGum)
      # make no info conventional to reference group
       gum2$treatmentGum <- relevel(gum2$treatmentGum, ref = "noi_gum2_notgood")

      dim(tomato)
      dim(apple)
      dim(gum1)
      dim(gum2)



####################
## Econometric Models


#######
#  Estimate the short a model for apples
   # a function for Beck-Katz standard errors clustered by groups
   my.vcovBK<-function(x){vcovBK(x,cluster="group")}
  # short model
			# write formula for short model
	  		formula.short<-as.formula(bids~treatment)
		  # random effects model
	  		short.model.re_A<-plm(
		   		formula=formula.short, 
			   	data=apple, 
				  effect = c("individual"),
				  model = c("random"),
				  random.method = c("swar"),
				  index=c("person_nr","treatment")
          )
   # show the results
      summary(short.model.re_A)
   # save coefficients
      coef.short.model.re_A<-coeftest(short.model.re_A,vcov=my.vcovBK)
   # fixed effects model which is needed for the hausman test
     short.model.fe_A<-plm(
       formula=formula.short, 
       data=apple, 
       effect = c("individual"),
       model = c("within"),
       random.method = c("swar"),
       index=c("person_nr","treatment"))
  # show the results
    summary(short.model.fe_A)
  # save coefficients
    coef.short.model.fe_A<-coeftest(short.model.fe_A,vcov=my.vcovBK)
  # Hausman Test for Apple
    HausmanTest_A <-  phtest(short.model.fe_A,short.model.re_A)

#######
#  Estimate the short model for tomato 
	  # write formula for short model
      formula.short<-as.formula(bids~treatment)
    # random effects model
  		short.model.re_T<-plm(
				formula=formula.short, 
				data=tomato, 
				effect = c("individual"),
				model = c("random"),
				random.method = c("swar"),
				index=c("person_nr","treatment"))
    # show the results
      summary(short.model.re_T)

    # save coefficients
      coef.short.model.re_T<-coeftest(short.model.re_T,vcov=my.vcovBK)
    # fixed effects model which is needed for the hausman test
      short.model.fe_T<-plm(
        formula=formula.short, 
         data=tomato, 
         effect = c("individual"),
         model = c("within"),
         random.method = c("swar"),
        index=c("person_nr","treatment"))
     # show the results
      summary(short.model.fe_T)
     # save coeffiecients
      coef.short.model.fe_T<-coeftest(short.model.fe_T,vcov=my.vcovBK)
     # Hausman Test for Tomato
      HausmanTest_T  <- phtest(short.model.fe_T,short.model.re_T)

   ############################
    # Write results for short model to csv file
    # for apple
    coef.short.model.re_A<-  data.frame(coef.short.model.re_A[,])
    coef.short.model.re_A$" "<-ifelse(coef.short.model.re_A[ ,4] < .01, "**",
                           ifelse(coef.short.model.re_A[ ,4] < .05, "*",
                            " "))
    # for tomato
    coef.short.model.re_T<-  data.frame(coef.short.model.re_T[,])
    coef.short.model.re_T$" "<-ifelse(coef.short.model.re_T[ ,4] < .01, "**",
                                  ifelse(coef.short.model.re_T[ ,4] < .05, "*",
                                         " "))

    # drop coumns not needed and save new data frame
     short_mod_table<-data.frame( coef.short.model.re_A[,c(1,2,5)],
                             coef.short.model.re_T[,c(1,2,5)])
     colnames(short_mod_table) <- c("Coeff. Appl.","St.Err."," ","Coeff. Toma.","St.Err."," ")
    # Reorder Rows
      order_columns <-  match(c( "(Intercept)", 
                    "treatmentnoi_apple_org",
                    "treatmentprod_apple_con",
                    "treatmentprod_apple_org",
                    "treatmentclaim_apple_con_envir", 
                    "treatmentclaim_apple_con_health", 
                    "treatmentclaim_apple_con_taste", 
                    "treatmentclaim_apple_org_envir",  
                    "treatmentclaim_apple_org_health",
                    "treatmentclaim_apple_org_taste"), 
                    rownames(coef.short.model.re_A)  
                    )
     short_mod_table<-short_mod_table[order_columns,]
     rownames(short_mod_table)<- c("Intercept", 
                              "Info: none",
                              "Info: production (Conventional)",
                              "Info: production (Organic)",
                              "Info: environmental claim (Conventional)",
                              "Info: health claim (Conventional)",
                              "Info: taste claim (Conventional)",
                              "Info: environmental claim (Organic)",
                              "Info: health claim (Organic)",
                              "Info: taste claim (Organic)")

     ### add Number of observations
         short_mod_table<- rbind(short_mod_table,c( nrow(short.model.re_A$model)/6, NA, NA, 
                                           nrow(short.model.re_T$model)/6, NA, NA))
         rownames(short_mod_table)[nrow(short_mod_table)]<-"Number of Observations"
     #### Add R2
         short_mod_table<- rbind(short_mod_table,c( summary(short.model.re_A)$r.squared[1], summary(short.model.re_A)$r.squared[2], NA, 
                                           summary(short.model.re_T)$r.squared[1], summary(short.model.re_T)$r.squared[2], NA))
         rownames(short_mod_table)[nrow(short_mod_table)]<-"R2, Adj. R2"
     #### Addd Error components
         short_mod_table<- rbind(short_mod_table,c( summary(short.model.re_A)[["ercomp"]]$sigma2$idios, summary(short.model.re_A)[["ercomp"]]$sigma2$id, NA, 
                                           summary(short.model.re_T)[["ercomp"]]$sigma2$idios, summary(short.model.re_T)[["ercomp"]]$sigma2$id, NA))
         rownames(short_mod_table)[nrow(short_mod_table)]<-"Share error: idiosyncratic, individual"
     ##### add Hausman Taylor Test
         short_mod_table<- rbind(short_mod_table,c(HausmanTest_A$statistic, HausmanTest_A$parameter,HausmanTest_A$p.value, 
                                          HausmanTest_T$statistic, HausmanTest_T$parameter,HausmanTest_T$p.value))
         rownames(short_mod_table)[nrow(short_mod_table)]<-"Hausman Test: statistic, DF, p-Values"

     # writeh short model (for apples and tomatoes) to a file     
     write.csv(short_mod_table, "regShort_A_T_v1.csv" )


###################################################
### Long Model

   #equation
    formula.longmodel.all<-as.formula(bids~uni*treatment
                                  + children*treatment
                                  + age 
                                  + gender 
                                  + income 
                                  #+ as.factor(employment)
                                  #+ as.factor(marital_status)
                                  #+ plan.buy_today 
                                  #+ buy_of
                                  + plan.buy_today
                                  #+ as.factor(oft.buy_of) # this is significan with right signs, but it is not interesting in our analysis interested in ceteris paribus interpretations
                                  #+ household_A # potentially intersting variable, but has no effect. As it complicates the programming because it is different in the tomato model, we do not include it in the model
                                  #+ household_T
                                  #+ as.factor(eat_lt ) # this is difficult, because there are many "other"
                                  #+ place
                                  #+ day
                                  #+ cash
                                  #+ time_decimal_start
                                    ) 
      # estimate random effects long model for apples

     longmodel.all.re_A<-plm(formula=formula.longmodel.all,data=apple,
                        effect=c("individual"),
                        model=c("random"),
                        random.method = c("swar"),
                        index=c("person_nr","treatment"))

    coeftest(longmodel.all.re_A,vcov=my.vcovBK)

  # check joint significance of university degree
   waldtest(longmodel.all.re_A, 8, vcov=my.vcovBK)
  # check joint significance of children
   waldtest(longmodel.all.re_A, 9, vcov=my.vcovBK)
  # check joint significance of uni, children,age, gender, income, plan.buy_today
   waldtest(longmodel.all.re_A, c(1:7), vcov=my.vcovBK)
   ### estimate fixed effects long model for appples
    longmodel.all.fe_A<-plm(formula=formula.longmodel.all,data=apple,
                        effect=c("individual"),
                        model=c("within"),
                        random.method = c("swar"),
                        index=c("person_nr","treatment"))

     HausmanTest.long.all_A  <- phtest(longmodel.all.fe_A,longmodel.all.re_A)
     coef.longmodel.all.re_A<-coeftest(longmodel.all.re_A,vcov=my.vcovBK)

   ### estimate random effects long model for tomatoes
    longmodel.all.re_T<-plm(formula=formula.longmodel.all,data=tomato,
                        effect=c("individual"),
                        model=c("random"),
                        random.method = c("swar"),
                    index=c("person_nr","treatment"))
       coeftest(longmodel.all.re_T,vcov=my.vcovBK)
   ### estimate fixed effects long model for tomatoes
       longmodel.all.fe_T<-plm(formula=formula.longmodel.all,data=tomato,
                    effect=c("individual"),
                    model=c("within"),
                    random.method = c("swar"),
                    index=c("person_nr","treatment"))
       HausmanTest.long.all_T  <- phtest(longmodel.all.fe_T,longmodel.all.re_T)
       coef.longmodel.all.re_T<-coeftest(longmodel.all.re_T,vcov=my.vcovBK)
  # check joint significance of university degree
    waldtest(longmodel.all.re_T, 8, vcov=my.vcovBK)
  # check joint significance of children
   waldtest(longmodel.all.re_T, 9, vcov=my.vcovBK)
  # check joint significance of uni, children,age, gender, income, plan.buy_today
   waldtest(longmodel.all.re_T, c(1:7), vcov=my.vcovBK)
 



###############
# make a table with results from long model (apples and tomatoes)
  # for apple
     coef.longmodel.all.re_A<-  data.frame(coef.longmodel.all.re_A[,])
     coef.longmodel.all.re_A$" "<-ifelse(coef.longmodel.all.re_A[ ,4] < .01, "**",
                                       ifelse(coef.longmodel.all.re_A[ ,4] < .05, "*",
                                              " "))
   # for tomato
     coef.longmodel.all.re_T<-  data.frame(coef.longmodel.all.re_T[,])
     coef.longmodel.all.re_T$" "<-ifelse(coef.longmodel.all.re_T[ ,4] < .01, "**",
                                       ifelse(coef.longmodel.all.re_T[ ,4] < .05, "*",
                                              " "))

   # drop columns not needed and save new data frame
     long_mod_all_table<-data.frame( coef.longmodel.all.re_A[,c(1,2,5)],
                                   coef.longmodel.all.re_T[,c(1,2,5)])
     colnames(long_mod_all_table) <- c("Coeff. Appl.","St.Err."," ","Coeff. Toma.","St.Err."," ")
   # Reorder Rows
     order_columns <-  match(c(
        "(Intercept)",
        "uniyes",                                     
        "childrenyes",                                
        "income2",
        "income3",                                 
        "income4",
        "plan.buy_todayno",   

        "treatmentnoi_apple_org",
        "uniyes:treatmentnoi_apple_org",
        "treatmentnoi_apple_org:childrenyes",         
        
        "treatmentprod_apple_con",         
        "uniyes:treatmentprod_apple_con",
        "treatmentprod_apple_con:childrenyes",

        "treatmentprod_apple_org",
        "uniyes:treatmentprod_apple_org",
        "treatmentprod_apple_org:childrenyes", 

        "treatmentclaim_apple_con_envir",
        "uniyes:treatmentclaim_apple_con_envir",
        "treatmentclaim_apple_con_envir:childrenyes", 
        "treatmentclaim_apple_con_health",         
        "uniyes:treatmentclaim_apple_con_health",
        "treatmentclaim_apple_con_health:childrenyes",
        "treatmentclaim_apple_con_taste",
        "uniyes:treatmentclaim_apple_con_taste",
        "treatmentclaim_apple_con_taste:childrenyes", 
        "treatmentclaim_apple_org_envir",          
        "uniyes:treatmentclaim_apple_org_envir",
        "treatmentclaim_apple_org_envir:childrenyes",
        "treatmentclaim_apple_org_health",
        "uniyes:treatmentclaim_apple_org_health",
        "treatmentclaim_apple_org_health:childrenyes",
        "treatmentclaim_apple_org_taste",          
        "uniyes:treatmentclaim_apple_org_taste",      
        "treatmentclaim_apple_org_taste:childrenyes"
        ), 
                        rownames(long_mod_all_table)  
        )
      
     # reorder the rows
      long_mod_all_table<-long_mod_all_table[order_columns,]
     # renamee the rows
         rownames(long_mod_all_table)<-  c("Intercept", "University degree", "Children in household", 
                                  "Income dummy: 10,000-15,000 Euro/year  (Base: over 15,000) ",
                                  "Income dummy: less than 10,000 Euro/year (Base: over 15,000) ",
                                  "Income dummy: other income (Base: over 15,000) ",
                                  "No plan to buy tomatoes or apples today",
                                    "Info: none",                               "  x University degree",             "  x Children in household",
                                    "Info: production (Conventional)",          "   x University degree",            "   x Children in household", 
                                    "Info: production (Organic)",               "    x University degree",           "    x Children in household",
                                    "Info: environmental claim (Conventional)", "     x University degree",          "     x Children in household",
                                    "Info: health claim (Conventional)",        "      x University degree",         "      x Children in household",
                                    "Info: taste claim (Conventional)",         "       x University degree",        "       x Children in household",
                                    "Info: environmental claim (Organic)",      "        x University degree",       "        x Children in household",
                                    "Info: health claim (Organic)",             "         x University degree",      "         x Children in household",
                                    "Info: taste claim (Organic)",              "          x University degree",     "          x Children in household")
  
         ### add Number of observations
          long_mod_all_table<- rbind(long_mod_all_table,c( nrow(longmodel.all.re_A$model)/6, NA, NA, 
                                                       nrow(longmodel.all.re_T$model)/6, NA, NA))
          rownames(long_mod_all_table)[nrow(long_mod_all_table)]<-"Number of Observations"
         #### Add R2
          long_mod_all_table<- rbind(long_mod_all_table,c( summary(longmodel.all.re_A)$r.squared[1], summary(longmodel.all.re_A)$r.squared[2], NA, 
                                                       summary(longmodel.all.re_T)$r.squared[1], summary(longmodel.all.re_T)$r.squared[2], NA))
          rownames(long_mod_all_table)[nrow(long_mod_all_table)]<-"R2, Adj. R2"
        #### Addd Error components
          long_mod_all_table<- rbind(long_mod_all_table,c( summary(longmodel.all.re_A)[["ercomp"]]$sigma2$idios, summary(longmodel.all.re_A)[["ercomp"]]$sigma2$id, NA, 
                                                       summary(longmodel.all.re_T)[["ercomp"]]$sigma2$idios, summary(longmodel.all.re_T)[["ercomp"]]$sigma2$id, NA))
          rownames(long_mod_all_table)[nrow(long_mod_all_table)]<-"Share error: idiosyncratic, individual"
        ##### add Hausman Taylor Test
          long_mod_all_table<- rbind(long_mod_all_table,c(HausmanTest.long.all_A$statistic, HausmanTest.long.all_A$parameter,HausmanTest.long.all_A$p.value, 
                                                      HausmanTest.long.all_T$statistic, HausmanTest.long.all_T$parameter,HausmanTest.long.all_T$p.value))
          rownames(long_mod_all_table)[nrow(long_mod_all_table)]<-"Hausman Test: statistic, DF, p-Values"


          # write table with results from long model (apples and tomatoes) to file
            write.csv(long_mod_all_table, "regLong_all_A_T_v1.csv" )

#######################################################
#### Additional specifications/tests for documentation (not discussed in the article)

# MERGING EDU LEVELS
#### Do an F-test to check if the four levels of education can be reduced to 
   # "uni" and "other". First, do it for apples
   # to do so, need to re-estimate the model with dummies being modelled explicitly 

    treat.dummies.Edu<-data.frame(model.matrix(~treatment*education,data=apple)[,-1])
    apple<-data.frame(apple, treat.dummies.Edu)
   formula.longmodel.edu.A.dummExplicit<-as.formula(bids~1+
                                     #treatment+
                                     education2+
                                     education3+
                                     education4+
                                      treatmentnoi_apple_org+         
                                           treatmentnoi_apple_org.education2+
                                           treatmentnoi_apple_org.education3+
                                           treatmentnoi_apple_org.education4+
                                      treatmentprod_apple_con+        
                                          treatmentprod_apple_con.education2+
                                          treatmentprod_apple_con.education3+
                                          treatmentprod_apple_con.education4+        
                                      treatmentprod_apple_org+  
                                          treatmentprod_apple_org.education2+
                                          treatmentprod_apple_org.education3+
                                          treatmentprod_apple_org.education4+  
                                      treatmentclaim_apple_con_envir +
                                          treatmentclaim_apple_con_envir.education2+
                                          treatmentclaim_apple_con_envir.education3+
                                          treatmentclaim_apple_con_envir.education4+
                                      treatmentclaim_apple_con_health +
                                          treatmentclaim_apple_con_health.education2 +
                                          treatmentclaim_apple_con_health.education3 +
                                          treatmentclaim_apple_con_health.education4 +
                                      treatmentclaim_apple_con_taste +
                                          treatmentclaim_apple_con_taste.education2 +
                                          treatmentclaim_apple_con_taste.education3 +
                                          treatmentclaim_apple_con_taste.education4 +
                                      treatmentclaim_apple_org_envir +
                                          treatmentclaim_apple_org_envir.education2 +
                                          treatmentclaim_apple_org_envir.education3 +
                                          treatmentclaim_apple_org_envir.education4 +
                                      treatmentclaim_apple_org_health +
                                          treatmentclaim_apple_org_health.education2 +
                                          treatmentclaim_apple_org_health.education3 +
                                          treatmentclaim_apple_org_health.education4 +
                                      treatmentclaim_apple_org_taste  +
                                          treatmentclaim_apple_org_taste.education2  +
                                          treatmentclaim_apple_org_taste.education3  +
                                          treatmentclaim_apple_org_taste.education4)  

   longmodel.edu.re_A.dummExplicit<-plm(formula=formula.longmodel.edu.A.dummExplicit,data=apple,
                    effect=c("individual"),
                    model=c("random"),
                    random.method = c("swar"),
                    index=c("person_nr","treatment"))

  # check if identical
   #test if education can be reduced to only uni with F-test
   
   waldtest(longmodel.edu.re_A.dummExplicit, .~ .  - education2
                                                   - education3
                                                   #- education4
                                                   - treatmentnoi_apple_org.education2-
                                                    treatmentnoi_apple_org.education3- 
                                                    #treatmentnoi_apple_org.education4   
                                                    treatmentprod_apple_con.education2-
                                                    treatmentprod_apple_con.education3- 
                                                    #treatmentprod_apple_con.education4   
                                                    treatmentprod_apple_org.education2-
                                                    treatmentprod_apple_org.education3- 
                                                    #treatmentprod_apple_org.education4  
                                                    treatmentclaim_apple_con_envir.education2-
                                                    treatmentclaim_apple_con_envir.education3- 
                                                    #treatmentclaim_apple_con_envir.education4 
                                                    treatmentclaim_apple_con_health.education2-
                                                    treatmentclaim_apple_con_health.education3- 
                                                    #treatmentclaim_apple_con_health.education4   
                                                    treatmentclaim_apple_con_taste.education2-
                                                    treatmentclaim_apple_con_taste.education3- 
                                                    #treatmentclaim_apple_con_taste.education4   
                                                    treatmentclaim_apple_org_envir.education2-
                                                    treatmentclaim_apple_org_envir.education3- 
                                                    #treatmentclaim_apple_org_envir.education4   
                                                    treatmentclaim_apple_org_health.education2-
                                                    treatmentclaim_apple_org_health.education3- 
                                                    #treatmentclaim_apple_org_health.education4   
                                                    treatmentclaim_apple_org_taste.education2-
                                                    treatmentclaim_apple_org_taste.education3 , vcov = my.vcovBK) 
                                                    #treatmentclaim_apple_org_taste.education4   

   ##################### End of F Tests for apples

   #### Same for tomatos: Test if education can be reduced to only uni with F-test
   # to do so, need to re-estimate the model with dummies being modelled explicitly 

    treat.dummies.Edu<-data.frame(model.matrix(~treatment*education,data=tomato)[,-1])
    tomato<-data.frame(tomato, treat.dummies.Edu)
   formula.longmodel.edu.T.dummExplicit<-as.formula(bids~1+
                                     #treatment+
                                      education2+
                                      education3+
                                      education4+
                                      treatmentnoi_tomato_org+         
                                           treatmentnoi_tomato_org.education2+
                                           treatmentnoi_tomato_org.education3+
                                           treatmentnoi_tomato_org.education4+
                                      treatmentprod_tomato_con+        
                                          treatmentprod_tomato_con.education2+
                                          treatmentprod_tomato_con.education3+
                                          treatmentprod_tomato_con.education4+        
                                      treatmentprod_tomato_org+  
                                          treatmentprod_tomato_org.education2+
                                          treatmentprod_tomato_org.education3+
                                          treatmentprod_tomato_org.education4+  
                                      treatmentclaim_tomato_con_envir +
                                          treatmentclaim_tomato_con_envir.education2+
                                          treatmentclaim_tomato_con_envir.education3+
                                          treatmentclaim_tomato_con_envir.education4+
                                      treatmentclaim_tomato_con_health +
                                          treatmentclaim_tomato_con_health.education2 +
                                          treatmentclaim_tomato_con_health.education3 +
                                          treatmentclaim_tomato_con_health.education4 +
                                      treatmentclaim_tomato_con_taste +
                                          treatmentclaim_tomato_con_taste.education2 +
                                          treatmentclaim_tomato_con_taste.education3 +
                                          treatmentclaim_tomato_con_taste.education4 +
                                      treatmentclaim_tomato_org_envir +
                                          treatmentclaim_tomato_org_envir.education2 +
                                          treatmentclaim_tomato_org_envir.education3 +
                                          treatmentclaim_tomato_org_envir.education4 +
                                      treatmentclaim_tomato_org_health +
                                          treatmentclaim_tomato_org_health.education2 +
                                          treatmentclaim_tomato_org_health.education3 +
                                          treatmentclaim_tomato_org_health.education4 +
                                      treatmentclaim_tomato_org_taste  +
                                          treatmentclaim_tomato_org_taste.education2  +
                                          treatmentclaim_tomato_org_taste.education3  +
                                          treatmentclaim_tomato_org_taste.education4)  

   longmodel.edu.re_T.dummExplicit<-plm(formula=formula.longmodel.edu.T.dummExplicit,data=tomato,
                    effect=c("individual"),
                    model=c("random"),
                    random.method = c("swar"),
                    index=c("person_nr","treatment"))

   

   waldtest(longmodel.edu.re_T.dummExplicit, .~ .  - education2
                                                   - education3
                                                   #- education4
                                                   - treatmentnoi_tomato_org.education2-
                                                    treatmentnoi_tomato_org.education3- 
                                                    #treatmentnoi_tomato_org.education4   
                                                    treatmentprod_tomato_con.education2-
                                                    treatmentprod_tomato_con.education3- 
                                                    #treatmentprod_tomato_con.education4   
                                                    treatmentprod_tomato_org.education2-
                                                    treatmentprod_tomato_org.education3- 
                                                    #treatmentprod_tomato_org.education4  
                                                    treatmentclaim_tomato_con_envir.education2-
                                                    treatmentclaim_tomato_con_envir.education3- 
                                                    #treatmentclaim_tomato_con_envir.education4 
                                                    treatmentclaim_tomato_con_health.education2-
                                                    treatmentclaim_tomato_con_health.education3- 
                                                    #treatmentclaim_tomato_con_health.education4   
                                                    treatmentclaim_tomato_con_taste.education2-
                                                    treatmentclaim_tomato_con_taste.education3- 
                                                    #treatmentclaim_tomato_con_taste.education4   
                                                    treatmentclaim_tomato_org_envir.education2-
                                                    treatmentclaim_tomato_org_envir.education3- 
                                                    #treatmentclaim_tomato_org_envir.education4   
                                                    treatmentclaim_tomato_org_health.education2-
                                                    treatmentclaim_tomato_org_health.education3- 
                                                    #treatmentclaim_tomato_org_health.education4   
                                                    treatmentclaim_tomato_org_taste.education2-
                                                    treatmentclaim_tomato_org_taste.education3 , vcov=my.vcovBK ) 
                                                    #treatmentclaim_tomato_org_taste.education4   
 
 #################### End of F Tests for tomatoes
 #                                       
 #                            
 # end of Test on summarizing education levels to "uni" and "other"

######################################

